
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer bx_create_buffer
#define yy_delete_buffer bx_delete_buffer
#define yy_flex_debug bx_flex_debug
#define yy_init_buffer bx_init_buffer
#define yy_flush_buffer bx_flush_buffer
#define yy_load_buffer_state bx_load_buffer_state
#define yy_switch_to_buffer bx_switch_to_buffer
#define yyin bxin
#define yyleng bxleng
#define yylex bxlex
#define yylineno bxlineno
#define yyout bxout
#define yyrestart bxrestart
#define yytext bxtext
#define yywrap bxwrap
#define yyalloc bxalloc
#define yyrealloc bxrealloc
#define yyfree bxfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE bxrestart(bxin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t bxleng;

extern FILE *bxin, *bxout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up bxtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up bxtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via bxrestart()), so that the user can continue scanning by
	 * just pointing bxin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when bxtext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t bxleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow bxwrap()'s to do buffer switches
 * instead of setting up a fresh bxin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void bxrestart (FILE *input_file  );
void bx_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE bx_create_buffer (FILE *file,int size  );
void bx_delete_buffer (YY_BUFFER_STATE b  );
void bx_flush_buffer (YY_BUFFER_STATE b  );
void bxpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void bxpop_buffer_state (void );

static void bxensure_buffer_stack (void );
static void bx_load_buffer_state (void );
static void bx_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER bx_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE bx_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE bx_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE bx_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *bxalloc (yy_size_t  );
void *bxrealloc (void *,yy_size_t  );
void bxfree (void *  );

#define yy_new_buffer bx_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        bxensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            bx_create_buffer(bxin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        bxensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            bx_create_buffer(bxin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *bxin = (FILE *) 0, *bxout = (FILE *) 0;

typedef int yy_state_type;

extern int bxlineno;

int bxlineno = 1;

extern char *bxtext;
#define yytext_ptr bxtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up bxtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	bxleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 203
#define YY_END_OF_BUFFER 204
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[445] =
    {   0,
        0,    0,    0,    0,    0,    0,  204,  201,    1,  199,
      187,  201,  200,  201,  184,  201,  189,  190,  180,  178,
      179,  181,  195,  195,  198,  201,  201,  173,  188,  197,
      186,  197,   18,    6,   45,  197,  197,  197,  172,  197,
      197,  197,  197,   12,  197,   13,   50,   26,   10,  197,
       62,  197,   82,   51,  197,  197,  185,  202,    1,  202,
      198,  202,    1,    0,  192,    0,  200,  196,    0,  191,
        0,  194,  195,    0,  183,  182,  197,  109,   93,  197,
      113,  110,   94,  119,  197,  114,  197,  111,   95,  197,
      197,   21,  164,  115,  197,  112,  118,   96,  197,  197,

       23,  167,  116,  197,  197,  197,  197,  197,  197,  165,
      197,  197,   29,  168,  197,  197,  169,  197,  197,  197,
      161,  197,  197,  170,   16,  197,  197,  197,  197,  197,
      197,    3,  197,   18,  197,  197,  197,  197,  197,  153,
      154,  197,  197,  197,  197,  197,  197,  197,   74,  197,
      197,  117,  197,  120,  197,  166,  197,  197,  197,  197,
      197,  197,  197,  197,   15,  197,  197,  197,  197,  197,
       52,  197,  197,  175,  176,  177,  196,  193,   92,   33,
      197,   47,   46,  100,  197,  197,  197,   35,    5,  197,
       44,  197,   98,  197,   59,  197,  197,  129,  135,  130,

      131,  134,  132,  197,  162,  133,  136,  197,  197,   29,
       38,  197,  197,   64,   36,  197,  197,   60,   37,  197,
      197,   39,  197,   34,  197,  197,    4,  197,  197,  197,
      197,  197,  197,  197,  155,  156,  157,  158,  159,  160,
      101,  137,  121,  102,  138,  122,  145,  152,  146,  147,
      150,  148,  197,   27,  197,  163,  149,  151,   75,    2,
      197,   97,  197,  197,   99,  197,   30,  197,  197,  197,
      197,   41,  197,   61,  197,   40,  197,  197,  197,  197,
      197,  197,   31,   32,  197,  197,  174,    7,   22,  197,
      197,  197,   67,   24,  197,   49,  197,  197,  172,   20,

      197,  197,  197,  197,  197,   11,   90,  197,  197,  197,
      197,  197,   48,  103,  139,  123,  104,  140,  124,  105,
      141,  125,  106,  142,  126,  107,  143,  127,  108,  144,
      128,   81,  197,   27,  197,  197,   83,   72,  197,   25,
        9,   66,  197,  197,   58,  197,  197,  197,  197,  197,
      197,  197,   14,   17,  197,  197,  197,  197,  197,  171,
      197,  197,  197,   84,   42,  197,  197,  197,  197,   73,
       56,  197,  197,  197,   86,  197,  197,   68,  197,  197,
      197,   79,   88,   82,  197,   43,   91,   63,   87,  197,
       16,   76,   19,  197,    0,  197,  197,  197,  197,  197,

        0,  197,   15,  197,  197,  197,  197,   57,    0,  197,
       53,   55,    0,   85,    0,    0,   80,  197,  197,    8,
      197,    0,  197,    0,    0,    0,   77,   54,  197,    0,
        0,   28,    0,   70,   69,   65,    0,    0,    0,   78,
        0,   71,   89,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    7,    1,    8,    9,   10,
       11,   12,   13,    1,   14,    1,   15,   16,   17,   18,
       19,   20,   21,   22,   22,   23,   24,    1,   25,   26,
        1,   27,   28,   29,   30,   30,   30,   30,   30,   30,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
        1,   32,    1,   33,   31,    1,   34,   35,   36,   37,

       38,   39,   40,   41,   42,   31,   43,   44,   45,   46,
       47,   48,   49,   50,   51,   52,   53,   54,   55,   56,
       57,   58,    1,   59,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[60] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    1,    1,    1,    1,    1,    4,
        5,    1,    1,    4,    6,    6,    6,    4,    4,    7,
        7,    7,    5,    5,    7,    5,    7,    5,    5,    5,
        7,    7,    7,    5,    7,    8,    5,    5,    1
    } ;

static yyconst flex_int16_t yy_base[457] =
    {   0,
        0,    0,   58,   60,   62,   64,  542,  543,  539,  543,
      543,   63,    0,    0,  543,   60,  543,  543,  543,  543,
      543,  543,   47,    0,  543,  514,  512,  543,  543,    0,
      543,   37,   56,   67,   86,  104,   54,  107,  500,  111,
      150,   84,   27,  499,   70,  139,  483,  175,  192,  144,
      489,   41,   79,   51,  489,  488,  543,  543,  530,  234,
      543,    0,  529,   75,  543,    0,    0,    0,  113,  543,
        0,  126,    0,    0,  543,  543,    0,    0,  486,  473,
        0,    0,  486,  142,  489,    0,  482,    0,    0,  479,
      471,   46,    0,    0,   81,    0,  103,    0,  489,  480,

      483,    0,    0,  464,  108,  463,  120,  474,  469,   46,
      474,  481,  461,    0,  461,  465,    0,  119,  459,  142,
        0,  461,  457,    0,  458,  101,  461,  450,  468,  448,
      464,    0,  462,  451,  454,  457,  456,  145,  184,  183,
      184,  441,  158,  440,  166,  156,  447,  181,  460,  441,
      445,  187,  449,  446,  451,  450,  177,  445,  441,  224,
      450,  450,  432,  427,  431,  442,  427,  440,  435,  431,
        0,  430,  429,    0,    0,    0,    0,    0,    0,    0,
      422,    0,    0,    0,  438,  435,  418,    0,    0,  429,
      430,  425,    0,  432,    0,  413,  424,    0,    0,    0,

        0,    0,    0,  429,    0,    0,    0,  410,  421,    0,
        0,  425,  411,    0,    0,  411,  405,    0,    0,  418,
      398,    0,  401,    0,  415,  400,    0,  413,  412,  412,
      402,  402,  396,  393,  211,  225,  228,  247,  256,  257,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  407,  174,  391,    0,    0,    0,    0,  394,
      386,    0,  402,  388,    0,  398,    0,  389,  388,  383,
      399,    0,  395,    0,  396,    0,  397,  392,  373,  392,
      377,  374,    0,    0,  373,  381,    0,  381,    0,  370,
      385,  369,    0,    0,  379,    0,  367,  383,    0,    0,

      366,  381,  369,  357,  377,    0,    0,  377,  368,  357,
      370,  350,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  355,    0,  358,  359,    0,    0,  351,    0,
        0,    0,  366,  354,    0,  362,  347,  364,  355,  355,
      357,  356,    0,    0,  347,  354,  353,  345,  338,    0,
      344,  334,  343,    0,    0,  337,  341,  337,  368,    0,
        0,  329,  330,  341,    0,  337,  333,  362,  339,  327,
      302,    0,    0,  308,  299,    0,    0,    0,    0,  306,
        0,    0,    0,  303,  279,  284,  272,  264,  294,  256,

      187,  265,    0,  270,  266,  265,  263,    0,  248,  249,
        0,    0,  253,    0,  259,  258,    0,  247,  243,    0,
      232,  227,  222,  225,  223,  224,    0,    0,  189,  199,
      186,    0,  160,  543,  543,    0,  142,  138,   96,  543,
       92,  543,  543,  543,  312,  320,  328,  333,  341,  347,
      107,  353,   87,  359,  365,  366
    } ;

static yyconst flex_int16_t yy_def[457] =
    {   0,
      444,    1,  445,  445,  445,  445,  444,  444,  444,  444,
      444,  446,  447,  448,  444,  449,  444,  444,  444,  444,
      444,  444,  450,  451,  444,  444,  444,  444,  444,  452,
      444,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  444,  444,  444,  444,
      444,  453,  444,  446,  444,  446,  447,  454,  449,  444,
      449,  450,  451,  455,  444,  444,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,

      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,   60,  456,  453,  454,  455,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,

      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,

      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  444,  452,  452,  452,  452,  452,

      444,  452,  452,  452,  452,  452,  452,  452,  444,  452,
      452,  452,  444,  452,  444,  444,  452,  452,  452,  452,
      452,  444,  452,  444,  444,  444,  452,  452,  452,  444,
      444,  452,  444,  444,  444,  452,  444,  444,  444,  444,
      444,  444,  444,    0,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444
    } ;

static yyconst flex_int16_t yy_nxt[603] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   24,   24,   24,
       24,   24,   24,   24,   25,   26,   27,   28,   29,   30,
       30,    8,   31,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   41,   42,   43,   44,   45,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   57,   59,
       10,   59,   10,   59,   10,   59,   10,   65,   70,   73,
       73,  128,   60,  129,   60,  165,   62,   78,   62,   65,
       79,  189,   61,  190,   61,  166,   61,  206,   61,  176,
       80,   71,   81,  207,   66,  170,   82,  112,  171,   83,

       87,  113,   74,   84,  114,   85,   66,   88,  131,   73,
       89,   86,  167,   90,   91,  132,   92,   93,  125,  168,
      126,   70,   94,   95,  191,  127,   96,   97,  169,   98,
       99,  443,  100,  442,  192,  101,  102,  104,  105,  106,
      107,  103,  108,  115,   71,  109,  193,  119,   73,   73,
      116,  221,  222,  194,  110,  199,  120,  117,  121,  111,
      122,  202,  213,  200,  123,  124,  124,  124,  124,  124,
      124,  124,  133,  134,  214,  203,  135,  160,  182,  183,
      216,  444,  233,  441,  440,  184,  234,  161,  136,  253,
      137,  139,  217,  162,  163,  254,  439,  140,  141,  235,

      236,  237,  238,  239,  240,  248,  255,  251,  142,  143,
      144,  145,  146,  249,  268,  333,  147,  241,  244,  242,
      245,  252,  257,  269,  334,  148,  149,  438,  258,  150,
      262,  415,  151,  152,  437,  153,  416,  243,  246,  154,
      436,  155,  156,  157,  263,  314,  158,  315,  159,  174,
      174,  174,  174,  174,  174,  174,  174,  174,  272,  317,
      430,  318,  320,  435,  321,  316,  273,  434,  175,  175,
      175,  433,  432,  175,  175,  175,  431,  429,  175,  319,
      175,  323,  322,  324,  175,  175,  175,  428,  175,  175,
      326,  329,  327,  330,  427,  426,  425,  424,  423,  422,

      421,  325,  420,  419,  418,  417,  414,  413,  412,  411,
      328,  331,   58,   58,   58,   58,   58,   58,   58,   58,
       64,  410,   64,   64,   64,   64,   64,   64,   67,  409,
       67,   67,   67,   67,   67,   67,   68,   68,   68,   68,
       68,   69,  408,   69,   69,   69,   69,   69,   69,   72,
      407,  406,  405,  404,   72,   77,   77,   77,   77,   77,
       77,  177,  177,  177,  177,  177,  177,  178,  178,  403,
      178,  175,  175,  175,  402,  401,  400,  399,  398,  397,
      396,  395,  394,  393,  392,  391,  390,  389,  360,  388,
      387,  386,  385,  384,  383,  382,  381,  380,  379,  378,

      377,  376,  375,  374,  373,  372,  371,  370,  369,  368,
      367,  366,  365,  364,  363,  362,  361,  360,  359,  358,
      357,  356,  355,  354,  353,  352,  351,  350,  349,  348,
      347,  346,  345,  344,  343,  342,  341,  340,  339,  338,
      337,  336,  335,  332,  313,  312,  311,  310,  309,  308,
      307,  306,  305,  304,  303,  302,  301,  300,  299,  298,
      297,  296,  295,  294,  293,  292,  291,  290,  289,  288,
      287,  286,  285,  284,  283,  267,  282,  281,  280,  279,
      278,  277,  276,  275,  274,  271,  270,  267,  266,  265,
      264,  261,  260,  259,  256,  250,  247,  232,  231,  230,

      229,  228,  227,  226,  225,  224,  223,  220,  219,  218,
      215,  212,  211,  210,  209,  208,  205,  204,  201,  198,
      197,  196,  195,  188,  187,  186,  185,  181,  180,  179,
       63,   63,  173,  172,  164,  138,  130,  118,   76,   75,
       63,  444,    7,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,

      444,  444
    } ;

static yyconst flex_int16_t yy_chk[603] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    3,
        3,    4,    4,    5,    5,    6,    6,   12,   16,   23,
       23,   43,    3,   43,    4,   52,    5,   32,    6,   64,
       32,   92,    3,   92,    4,   52,    5,  110,    6,  453,
       32,   16,   32,  110,   12,   54,   33,   37,   54,   33,

       34,   37,   23,   33,   37,   33,   64,   34,   45,  451,
       34,   33,   53,   34,   34,   45,   34,   34,   42,   53,
       42,   69,   34,   35,   95,   42,   35,   35,   53,   35,
       35,  441,   35,  439,   95,   35,   35,   36,   36,   36,
       36,   35,   36,   38,   69,   36,   97,   40,   72,   72,
       38,  126,  126,   97,   36,  105,   40,   38,   40,   36,
       40,  107,  118,  105,   40,   41,   41,   41,   41,   41,
       41,   41,   46,   46,  118,  107,   46,   50,   84,   84,
      120,   72,  138,  438,  437,   84,  138,   50,   46,  146,
       46,   48,  120,   50,   50,  146,  433,   48,   48,  139,

      139,  139,  139,  139,  139,  143,  146,  145,   48,   48,
       48,   48,   48,  143,  157,  254,   48,  140,  141,  140,
      141,  145,  148,  157,  254,   48,   49,  431,  148,   49,
      152,  401,   49,   49,  430,   49,  401,  140,  141,   49,
      429,   49,   49,   49,  152,  235,   49,  235,   49,   60,
       60,   60,   60,   60,   60,   60,   60,   60,  160,  236,
      422,  236,  237,  426,  237,  235,  160,  425,   60,   60,
       60,  424,  423,   60,   60,   60,  422,  421,   60,  236,
       60,  238,  237,  238,   60,   60,   60,  419,   60,   60,
      239,  240,  239,  240,  418,  416,  415,  413,  410,  409,

      407,  238,  406,  405,  404,  402,  400,  399,  398,  397,
      239,  240,  445,  445,  445,  445,  445,  445,  445,  445,
      446,  396,  446,  446,  446,  446,  446,  446,  447,  395,
      447,  447,  447,  447,  447,  447,  448,  448,  448,  448,
      448,  449,  394,  449,  449,  449,  449,  449,  449,  450,
      390,  385,  384,  381,  450,  452,  452,  452,  452,  452,
      452,  454,  454,  454,  454,  454,  454,  455,  455,  380,
      455,  456,  456,  456,  379,  378,  377,  376,  374,  373,
      372,  369,  368,  367,  366,  363,  362,  361,  359,  358,
      357,  356,  355,  352,  351,  350,  349,  348,  347,  346,

      344,  343,  339,  336,  335,  333,  312,  311,  310,  309,
      308,  305,  304,  303,  302,  301,  298,  297,  295,  292,
      291,  290,  288,  286,  285,  282,  281,  280,  279,  278,
      277,  275,  273,  271,  270,  269,  268,  266,  264,  263,
      261,  260,  255,  253,  234,  233,  232,  231,  230,  229,
      228,  226,  225,  223,  221,  220,  217,  216,  213,  212,
      209,  208,  204,  197,  196,  194,  192,  191,  190,  187,
      186,  185,  181,  173,  172,  170,  169,  168,  167,  166,
      165,  164,  163,  162,  161,  159,  158,  156,  155,  154,
      153,  151,  150,  149,  147,  144,  142,  137,  136,  135,

      134,  133,  131,  130,  129,  128,  127,  125,  123,  122,
      119,  116,  115,  113,  112,  111,  109,  108,  106,  104,
      101,  100,   99,   91,   90,   87,   85,   83,   80,   79,
       63,   59,   56,   55,   51,   47,   44,   39,   27,   26,
        9,    7,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,

      444,  444
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int bx_flex_debug;
int bx_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *bxtext;
#line 1 "lexer.l"
#line 2 "lexer.l"
/////////////////////////////////////////////////////////////////////////
// $Id: lexer.c 12184 2014-02-11 20:51:18Z sshwarts $
/////////////////////////////////////////////////////////////////////////

#include <stdlib.h>
#include <string.h>

#ifdef WIN32
	#include <io.h>
	#define YY_NO_UNISTD_H
#endif

#include "debug.h"
#if BX_DEBUGGER

#include "parser.h"

int bx_yyinput(char *buf, int max_size);
#undef YY_INPUT
#define YY_INPUT(buf, ret, max_size) (ret = bx_yyinput(buf, max_size))

static char    *lex_input_ptr = NULL;
static unsigned lex_input_size = 0;

#if BX_SUPPORT_X86_64
  #define LONG_MODE_8BL_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_8BL_REG); }
  #define LONG_MODE_16B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_16B_REG); }
  #define LONG_MODE_32B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_32B_REG); }
  #define LONG_MODE_64B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_64B_REG); }
#else
  #define LONG_MODE_8BL_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_16B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_32B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_64B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
#endif

#if BX_SUPPORT_EVEX
  #define EVEX_OPMASK_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_OPMASK_REG); }
#else
  #define EVEX_OPMASK_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
#endif



#line 807 "<stdout>"

#define INITIAL 0
#define EXAMINE 1
#define DISASM 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int bxlex_destroy (void );

int bxget_debug (void );

void bxset_debug (int debug_flag  );

YY_EXTRA_TYPE bxget_extra (void );

void bxset_extra (YY_EXTRA_TYPE user_defined  );

FILE *bxget_in (void );

void bxset_in  (FILE * in_str  );

FILE *bxget_out (void );

void bxset_out  (FILE * out_str  );

yy_size_t bxget_leng (void );

char *bxget_text (void );

int bxget_lineno (void );

void bxset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int bxwrap (void );
#else
extern int bxwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( bxtext, bxleng, 1, bxout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( bxin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( bxin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, bxin))==0 && ferror(bxin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(bxin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int bxlex (void);

#define YY_DECL int bxlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after bxtext and bxleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 59 "lexer.l"

#line 993 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! bxin )
			bxin = stdin;

		if ( ! bxout )
			bxout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			bxensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				bx_create_buffer(bxin,YY_BUF_SIZE );
		}

		bx_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of bxtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 445 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 543 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 60 "lexer.l"
; // eat up whitespace
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 61 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SET); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 62 "lexer.l"
{ bxlval.bval = 1; return(BX_TOKEN_ON); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 63 "lexer.l"
{ bxlval.bval = 0; return(BX_TOKEN_OFF); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 64 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CRC); }
	YY_BREAK
case 6:
#line 66 "lexer.l"
case 7:
#line 67 "lexer.l"
case 8:
YY_RULE_SETUP
#line 67 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CONTINUE); }
	YY_BREAK
case 9:
#line 69 "lexer.l"
case 10:
YY_RULE_SETUP
#line 69 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STEPN); }
	YY_BREAK
case 11:
#line 71 "lexer.l"
case 12:
#line 72 "lexer.l"
case 13:
YY_RULE_SETUP
#line 72 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STEP_OVER); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 73 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LIST_BREAK); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 74 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_VBREAKPOINT); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 75 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LBREAKPOINT); }
	YY_BREAK
case 17:
#line 77 "lexer.l"
case 18:
#line 78 "lexer.l"
case 19:
YY_RULE_SETUP
#line 78 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PBREAKPOINT); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 79 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_INFO); }
	YY_BREAK
case 21:
#line 81 "lexer.l"
case 22:
YY_RULE_SETUP
#line 81 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CONTROL_REGS); }
	YY_BREAK
case 23:
#line 83 "lexer.l"
case 24:
YY_RULE_SETUP
#line 83 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEBUG_REGS); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 84 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SEGMENT_REGS); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 85 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_R); }
	YY_BREAK
case 27:
#line 87 "lexer.l"
case 28:
YY_RULE_SETUP
#line 87 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_REGS); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 88 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_FPU); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 89 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_XMM); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 90 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_YMM); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 91 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ZMM); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 92 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_AVX); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 93 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_MMX); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 94 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CPU); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 95 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IDT); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 96 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IVT); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 97 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GDT); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 98 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LDT); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 99 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TSS); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 100 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TAB); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 101 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LINUX); }
	YY_BREAK
case 43:
#line 103 "lexer.l"
case 44:
#line 104 "lexer.l"
case 45:
YY_RULE_SETUP
#line 104 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEL_BREAKPOINT); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 105 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ENABLE_BREAKPOINT); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 106 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISABLE_BREAKPOINT); }
	YY_BREAK
case 48:
#line 108 "lexer.l"
case 49:
#line 109 "lexer.l"
case 50:
YY_RULE_SETUP
#line 109 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_QUIT); }
	YY_BREAK
case 51:
#line 111 "lexer.l"
case 52:
YY_RULE_SETUP
#line 111 "lexer.l"
{ BEGIN(EXAMINE); bxlval.sval = strdup(bxtext); return(BX_TOKEN_EXAMINE); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 112 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_RESTORE); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 113 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WRITEMEM); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 114 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SETPMEM); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 115 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_QUERY); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 116 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PENDING); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 117 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TAKE); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 118 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DMA); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 119 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IRQ); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 120 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TLB); }
	YY_BREAK
case 62:
#line 122 "lexer.l"
case 63:
YY_RULE_SETUP
#line 122 "lexer.l"
{ BEGIN(DISASM); bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISASM); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 123 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_HEX); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 124 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_INSTRUMENT); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 125 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STOP); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 126 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DOIT); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 127 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACE); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 128 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACEREG); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 129 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACEMEM); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 130 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SWITCH_MODE); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 131 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SIZE); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 132 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PTIME); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 133 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TIMEBP); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 134 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TIMEBP_ABSOLUTE); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 135 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_MODEBP); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 136 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_VMEXITBP); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 137 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PRINT_STACK); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 138 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WATCH); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 139 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_UNWATCH); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 140 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_READ); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 141 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WRITE); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 142 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SHOW); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 143 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LOAD_SYMBOLS); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 144 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SYMBOLS); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 145 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LIST_SYMBOLS); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 146 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GLOBAL); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 147 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WHERE); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 148 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PRINT_STRING); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 149 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PAGE); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 150 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEVICE); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 151 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ALL); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 152 "lexer.l"
{ bxlval.uval = BX_DBG_REG8L_AL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 153 "lexer.l"
{ bxlval.uval = BX_DBG_REG8L_BL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 154 "lexer.l"
{ bxlval.uval = BX_DBG_REG8L_CL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 155 "lexer.l"
{ bxlval.uval = BX_DBG_REG8L_DL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 156 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_SIL); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 157 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_DIL); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 158 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_SPL); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 159 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_BPL); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 160 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R8);  }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 161 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R9);  }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 162 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R10); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 163 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R11); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 164 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R12); }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 165 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R13); }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 166 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R14); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 167 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R15); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 168 "lexer.l"
{ bxlval.uval = BX_DBG_REG8H_AH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 169 "lexer.l"
{ bxlval.uval = BX_DBG_REG8H_BH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 170 "lexer.l"
{ bxlval.uval = BX_DBG_REG8H_CH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 171 "lexer.l"
{ bxlval.uval = BX_DBG_REG8H_DH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 172 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_AX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 173 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_BX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 174 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_CX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 175 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_DX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 176 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_SI; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 177 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_DI; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 178 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_BP; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 179 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_SP; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 180 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R8);  }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 181 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R9);  }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 182 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R10); }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 183 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R11); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 184 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R12); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 185 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R13); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 186 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R14); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 187 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R15); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 188 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EAX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 189 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EBX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 190 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_ECX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 191 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EDX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 192 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_ESI; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 193 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EDI; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 194 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EBP; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 195 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_ESP; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 196 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R8);  }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 197 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R9);  }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 198 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R10); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 199 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R11); }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 200 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R12); }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 201 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R13); }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 202 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R14); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 203 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R15); }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 204 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RAX); }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 205 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RBX); }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 206 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RCX); }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 207 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RDX); }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 208 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RSI); }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 209 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RDI); }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 210 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RSP); }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 211 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RBP); }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 212 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R8);  }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 213 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R9);  }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 214 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R10); }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 215 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R11); }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 216 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R12); }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 217 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R13); }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 218 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R14); }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 219 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R15); }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 220 "lexer.l"
{ return(BX_TOKEN_REG_IP); }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 221 "lexer.l"
{ return(BX_TOKEN_REG_EIP);}
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 222 "lexer.l"
{ return(BX_TOKEN_REG_RIP);}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 223 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_CS; return(BX_TOKEN_CS); }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 224 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_ES; return(BX_TOKEN_ES); }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 225 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_SS; return(BX_TOKEN_SS); }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 226 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_DS; return(BX_TOKEN_DS); }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 227 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_FS; return(BX_TOKEN_FS); }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 228 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_GS; return(BX_TOKEN_GS); }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 229 "lexer.l"
{ EVEX_OPMASK_REG(bxtext[1] - '0'); }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 230 "lexer.l"
{ bxlval.uval = 0; return (BX_TOKEN_FLAGS); }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 231 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_HELP); }
	YY_BREAK
case 173:
#line 233 "lexer.l"
case 174:
YY_RULE_SETUP
#line 233 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CALC); }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 234 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_XFORMAT); }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 235 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_XFORMAT); }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 236 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISFORMAT); }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 237 "lexer.l"
{ return ('+'); }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 238 "lexer.l"
{ return ('-'); }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 239 "lexer.l"
{ return ('*'); }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 240 "lexer.l"
{ return ('/'); }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 241 "lexer.l"
{ return (BX_TOKEN_RSHIFT); }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 242 "lexer.l"
{ return (BX_TOKEN_LSHIFT); }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 243 "lexer.l"
{ return ('&'); }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 244 "lexer.l"
{ return ('|'); }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 245 "lexer.l"
{ return ('^'); }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 246 "lexer.l"
{ return ('!'); }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 247 "lexer.l"
{ return ('@'); }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 248 "lexer.l"
{ return ('('); }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 249 "lexer.l"
{ return (')'); }
	YY_BREAK
case 191:
#line 251 "lexer.l"
case 192:
YY_RULE_SETUP
#line 251 "lexer.l"
{ bxlval.sval = strdup(bxtext+1); bxlval.sval[strlen(bxlval.sval)-1] = 0; return(BX_TOKEN_STRING); }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 252 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 16); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 253 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 8); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 254 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 10); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 255 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SYMBOLNAME); }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 256 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 257 "lexer.l"
{ return ('\n'); }
	YY_BREAK
case 199:
/* rule 199 can match eol */
YY_RULE_SETUP
#line 258 "lexer.l"
{ return ('\n'); }
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 259 "lexer.l"
; // eat up comments '//'
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 260 "lexer.l"
{ return(bxtext[0]); }
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 261 "lexer.l"
{ BEGIN(INITIAL); unput(*bxtext); }
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 262 "lexer.l"
ECHO;
	YY_BREAK
#line 2038 "<stdout>"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(EXAMINE):
case YY_STATE_EOF(DISASM):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed bxin at a new source and called
			 * bxlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = bxin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( bxwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * bxtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of bxlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					bxrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			bxrestart(bxin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) bxrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 445 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 445 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 444);

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up bxtext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					bxrestart(bxin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( bxwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve bxtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void bxrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        bxensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            bx_create_buffer(bxin,YY_BUF_SIZE );
	}

	bx_init_buffer(YY_CURRENT_BUFFER,input_file );
	bx_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void bx_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		bxpop_buffer_state();
	 *		bxpush_buffer_state(new_buffer);
     */
	bxensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	bx_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (bxwrap()) processing, but the only time this flag
	 * is looked at is after bxwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void bx_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	bxin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE bx_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) bxalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in bx_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) bxalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in bx_create_buffer()" );

	b->yy_is_our_buffer = 1;

	bx_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with bx_create_buffer()
 * 
 */
    void bx_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		bxfree((void *) b->yy_ch_buf  );

	bxfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a bxrestart() or at EOF.
 */
    static void bx_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	bx_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then bx_init_buffer was _probably_
     * called from bxrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void bx_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		bx_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void bxpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	bxensure_buffer_stack();

	/* This block is copied from bx_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from bx_switch_to_buffer. */
	bx_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void bxpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	bx_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		bx_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void bxensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)bxalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in bxensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)bxrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in bxensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE bx_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) bxalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in bx_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	bx_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to bxlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       bx_scan_bytes() instead.
 */
YY_BUFFER_STATE bx_scan_string (yyconst char * yystr )
{
    
	return bx_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to bxlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE bx_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) bxalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in bx_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = bx_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in bx_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up bxtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		bxtext[bxleng] = (yy_hold_char); \
		(yy_c_buf_p) = bxtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		bxleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int bxget_lineno  (void)
{
        
    return bxlineno;
}

/** Get the input stream.
 * 
 */
FILE *bxget_in  (void)
{
        return bxin;
}

/** Get the output stream.
 * 
 */
FILE *bxget_out  (void)
{
        return bxout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t bxget_leng  (void)
{
        return bxleng;
}

/** Get the current token.
 * 
 */

char *bxget_text  (void)
{
        return bxtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void bxset_lineno (int  line_number )
{
    
    bxlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see bx_switch_to_buffer
 */
void bxset_in (FILE *  in_str )
{
        bxin = in_str ;
}

void bxset_out (FILE *  out_str )
{
        bxout = out_str ;
}

int bxget_debug  (void)
{
        return bx_flex_debug;
}

void bxset_debug (int  bdebug )
{
        bx_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from bxlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    bxin = stdin;
    bxout = stdout;
#else
    bxin = (FILE *) 0;
    bxout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * bxlex_init()
     */
    return 0;
}

/* bxlex_destroy is for both reentrant and non-reentrant scanners. */
int bxlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		bx_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		bxpop_buffer_state();
	}

	/* Destroy the stack itself. */
	bxfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * bxlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *bxalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *bxrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void bxfree (void * ptr )
{
	free( (char *) ptr );	/* see bxrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 262 "lexer.l"



  int
bx_yyinput(char *buf, int max_size)
{
  int len;

  if (lex_input_size == 0) {
    fprintf(stderr, "lex: no characters in string input buffer.\n");
    exit(1);
  }

  len = strlen(lex_input_ptr) + 1;
  if (len > max_size)
    len = max_size;

  memcpy(buf, lex_input_ptr, len);

  return(len);
}

  void
bx_add_lex_input(char *buf)
{
  lex_input_ptr  = buf;
  lex_input_size = strlen(buf);

  // Since we're parsing from strings, flush out
  // all current buffer state, so the next read
  // requests from yyinput

  bx_flush_buffer( YY_CURRENT_BUFFER );
}

#endif /* if BX_DEBUGGER */

